pub unsafe extern "C" fn __wrap_malloc(size: usize) -> *mut c_voidExpand description
Allocates memory from DR’s global memory pool, but mimics the behavior of malloc. Memory must be freed with __wrap_free(). The __wrap routines are intended to be used with ld’s -wrap option to replace a client’s use of malloc, realloc, and free with internal versions that allocate memory from DR’s private pool. With -wrap, clients can link to libraries that allocate heap memory without interfering with application allocations. The returned address is guaranteed to be double-pointer-aligned: aligned to 16 bytes for 64-bit; aligned to 8 bytes for 32-bit.