dr_app_pc_from_cache_pc

Function dr_app_pc_from_cache_pc 

pub unsafe extern "C" fn dr_app_pc_from_cache_pc(
    cache_pc: *mut byte,
) -> app_pc
Given a code cache pc, returns the corresponding application pc. This involves translating the state and thus may incur calls to the basic block and trace events (see dr_register_bb_event()). If translation fails, returns NULL. This routine may not be called from a thread exit event.