pub unsafe extern "C" fn dr_client_iterator_hasnext(
iter: *mut dr_client_iterator_t,
) -> bool_Expand description
\param[in] iter A client iterator created with dr_client_iterator_start()
\return true if there are more clients to iterate over
pub unsafe extern "C" fn dr_client_iterator_hasnext(
iter: *mut dr_client_iterator_t,
) -> bool_\param[in] iter A client iterator created with dr_client_iterator_start()
\return true if there are more clients to iterate over