dr_create_memory_dump

Function dr_create_memory_dump 

pub unsafe extern "C" fn dr_create_memory_dump(
    spec: *mut dr_memory_dump_spec_t,
) -> bool_
Requests that DR create a memory dump file of the current process. The type of dump is specified by \p spec.

\return whether successful.

\note this function is only supported on Windows and X64 Linux only. For X64 Linux, this API has the same restriction as dr_suspend_all_other_threads_ex(). For X86_64 platform, fast FP save and restore (fxsave64) support is required. And mixed mode (a process mixing 64-bit and 32-bit code) is not supported.