pub unsafe extern "C" fn dr_exit_process(exit_code: c_int)Expand description
Exits the process, first performing a full cleanup that will trigger the exit event (dr_register_exit_event()). The process exit code is set to \p exit_code.
On Linux, only the bottom 8 bits of \p exit_code will be honored for a normal exit. If bits 9..16 are not all zero, DR will send an unhandled signal of that signal number instead of performing a normal exit.
\note Calling this from \p dr_client_main or from the primary thread’s initialization event is not guaranteed to always work, as DR may invoke a thread exit event where a thread init event was never called. We recommend using dr_abort_with_code() or waiting for full initialization prior to use of this routine.