dr_get_error_code

Function dr_get_error_code 

pub unsafe extern "C" fn dr_get_error_code(
    drcontext: *mut c_void,
) -> dr_error_code_t
Returns the error code of the last failed API routine. Users should check whether or not the API routine that they just called has failed prior to calling this function.

\warning Not all API routines currently support the registering of an error code upon their failure. Therefore, check the routine’s documentation to see whether it supports setting error codes.