pub unsafe extern "C" fn dr_get_integer_option(
option_name: *const c_char,
val: *mut uint64,
) -> bool_Expand description
Read the value of an integer DynamoRIO runtime option named \p option_name into \p val. This includes boolean options. Options are listed in \ref sec_options. DynamoRIO has many other undocumented options which may be queried through this API, but they are not officially supported. \warning Always pass a full uint64 for \p val even if the option is a smaller integer to avoid overwriting nearby data. \return false if no option named \p option_name exists, and true otherwise.