dr_get_random_value

Function dr_get_random_value 

pub unsafe extern "C" fn dr_get_random_value(max: uint) -> uint
Returns a pseudo-random number in the range [0..max). The pseudo-random sequence can be repeated by passing the seed used during a run to the next run via the -prng_seed runtime option.