dr_map_executable_file

Function dr_map_executable_file 

pub unsafe extern "C" fn dr_map_executable_file(
    filename: *const c_char,
    flags: dr_map_executable_flags_t,
    size: *mut usize,
) -> *mut byte
Loads \p filename as an executable file for examination, rather than for execution. No entry point, initialization, or constructor code is executed, nor is any thread-local storage or other resources set up. Returns the size (which may include unmappped gaps) in \p size. The return value of the function is the base address at which the file is mapped.

\note Not currently supported on Mac OSX.