pub unsafe extern "C" fn dr_memory_is_readable(
pc: *const byte,
size: usize,
) -> bool_Expand description
Checks to see that all bytes with addresses in the range [\p pc, \p pc + \p size - 1] are readable and that reading from that range won’t generate an exception (see also dr_safe_read() and DR_TRY_EXCEPT()). \note Nothing guarantees that the memory will stay readable for any length of time. \note On Linux, especially if the app is in the middle of loading a library and has not properly set up the .bss yet, a page that seems readable can still generate SIGBUS if beyond the end of an mmapped file. Use dr_safe_read() or DR_TRY_EXCEPT() to avoid such problems.