dr_memory_protect

Function dr_memory_protect 

pub unsafe extern "C" fn dr_memory_protect(
    base: *mut c_void,
    size: usize,
    new_prot: uint,
) -> bool_
Modifies the memory protections of the region from \p start through \p start + \p size. Modification of memory allocated by DR or of the DR or client libraries themselves is allowed under the assumption that the client knows what it is doing. Modification of the ntdll.dll library on Windows is not allowed. Returns true if successful.