pub unsafe extern "C" fn dr_module_import_iterator_next(
iter: *mut dr_module_import_iterator_t,
) -> *mut dr_module_import_tExpand description
Advances the passed-in iterator and returns the current module import in the iterator. The pointer returned is only valid until the next call to dr_module_import_iterator_next() or dr_module_import_iterator_stop().
\note ELF does not import directly from other modules.