pub unsafe extern "C" fn dr_module_iterator_hasnext(
mi: *mut dr_module_iterator_t,
) -> bool_Expand description
Returns true if there is another loaded module in the iterator.
pub unsafe extern "C" fn dr_module_iterator_hasnext(
mi: *mut dr_module_iterator_t,
) -> bool_Returns true if there is another loaded module in the iterator.