pub unsafe extern "C" fn dr_module_iterator_stop(
mi: *mut dr_module_iterator_t,
)Expand description
User should call this routine to free the module iterator.
pub unsafe extern "C" fn dr_module_iterator_stop(
mi: *mut dr_module_iterator_t,
)User should call this routine to free the module iterator.