pub unsafe extern "C" fn dr_mutex_create() -> *mut c_voidExpand description
Initializes a mutex.
Warning: there are restrictions on when DR-provided mutexes, and locks in general, can be held by a client: no lock should be held while application code is executing in the code cache. Locks can be used while inside client code reached from clean calls out of the code cache, but they must be released before returning to the cache. A lock must also be released by the same thread that acquired it. Failing to follow these restrictions can lead to deadlocks.