pub unsafe extern "C" fn dr_query_memory(
pc: *const byte,
base_pc: *mut *mut byte,
size: *mut usize,
prot: *mut uint,
) -> bool_Expand description
An os neutral method for querying a memory address. Returns true iff a memory region containing \p pc is found. If found additional information about the memory region is returned in the optional out arguments \p base_pc, \p size, and \p prot where \p base_pc is the start address of the memory region continaing \p pc, \p size is the size of said memory region and \p prot is an ORed combination of DR_MEMPROT_* flags describing its current protection.
\note To examine only application memory, skip memory for which dr_memory_is_dr_internal() or dr_memory_is_in_client() returns true.
\note DR may mark writable code pages as read-only but pretend they’re writable. When this happens, it will include both #DR_MEMPROT_WRITE and #DR_MEMPROT_PRETEND_WRITE in \p prot.