pub unsafe extern "C" fn dr_raw_mem_alloc(
size: usize,
prot: uint,
addr: *mut c_void,
) -> *mut c_voidExpand description
\warning This raw memory allocation interface is in flux and is subject to change in the next release. Consider it experimental in this release.
Allocates \p size bytes (page size aligned) of memory as a separate allocation at preferred base \p addr that must be page size aligned, allowing for separate protection. If \p addr is NULL, an arbitrary address is picked.
The \p prot protection should use the DR_MEMPROT_READ, DR_MEMPROT_WRITE, and DR_MEMPROT_EXEC bits. The allocated memory is not considered to be DynamoRIO or tool memory and thus is not kept separate from the application. Use of this memory is at the client’s own risk.
The resulting memory is guaranteed to be initialized to all zeroes.
Returns the actual address allocated or NULL if memory allocation at preferred base fails.