dr_register_module_unload_event

Function dr_register_module_unload_event 

pub unsafe extern "C" fn dr_register_module_unload_event(
    func: Option<unsafe extern "C" fn(drcontext: *mut c_void, info: *const module_data_t)>,
)
Registers a callback function for the module unload event. DR calls \p func whenever the application unloads a module. \note The module_data_t \p *info passed to the callback routine is valid only for the duration of the callback and should not be freed; a persistent copy can be made with dr_copy_module_data().