dr_safe_write

Function dr_safe_write 

pub unsafe extern "C" fn dr_safe_write(
    base: *mut c_void,
    size: usize,
    in_buf: *const c_void,
    bytes_written: *mut usize,
) -> bool_
Safely writes \p size bytes from buffer \p in_buf to address \p base. Writing is done without the possibility of an exception occurring. Returns true if the entire \p size bytes were written; otherwise returns false and if \p bytes_written is non-NULL returns the partial number of bytes written in \p bytes_written. \note See also DR_TRY_EXCEPT().