dr_snwprintf

Function dr_snwprintf 

pub unsafe extern "C" fn dr_snwprintf(
    buf: *mut wchar_t,
    max: usize,
    fmt: *const wchar_t,
    ...
) -> c_int
Wide character version of dr_snprintf(). All of the comments for dr_snprintf() apply, except for the hs or S format specifiers. On Windows, these will assume that the input is UTF-8, and will convert to UTF-16. On Linux, they will widen a single-byte character string into a wchar_t character string with zero as the high-order bytes.