pub unsafe extern "C" fn dr_unregister_client(
process_name: *const c_char,
pid: process_id_t,
global: bool_,
dr_platform: dr_platform_t,
client_id: client_id_t,
) -> dr_config_status_tExpand description
Unregister a client for a particular process.
\param[in] process_name A NULL-terminated string specifying the name of the target process. The string should identify the base name of the process, not the full path of the executable (e.g., calc.exe).
\param[in] pid A process id of a target process, typically just created and suspended via dr_inject_process_exit(). If pid != 0, the one-time configuration for that pid will be modified. If pid == 0, the general configuration for process_name will be modified.
\param[in] global Whether to use global or user-local config files. On Windows, global config files are stored in a dir pointed at by the DYNAMORIO_HOME registry key. On Linux, they are in /etc/dynamorio. Administrative privileges may be needed if global is true. Note that DynamoRIO gives local config files precedence when both exist. The caller must separately create the global directory.
\param[in] dr_platform Configurations are kept separate for 32-bit processes and 64-bit processes. This parameter allows selecting which of those configurations to unset.
\param[in] client_id The unique client ID provided at client registration.
\return A dr_config_status_t code indicating the result of unregistration.