dr_unregister_module_load_event

Function dr_unregister_module_load_event 

pub unsafe extern "C" fn dr_unregister_module_load_event(
    func: Option<unsafe extern "C" fn(drcontext: *mut c_void, info: *const module_data_t, loaded: bool_)>,
) -> bool_
Unregister a callback for the module load event. \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).

\note Unregistering for this event is not supported during the basic block event.