pub unsafe extern "C" fn dr_unregister_thread_init_event(
func: Option<unsafe extern "C" fn(drcontext: *mut c_void)>,
) -> bool_Expand description
Unregister a callback function for the thread initialization event. \return true if unregistration is successful and false if it is not (e.g., \p func was not registered).