dr_using_app_state

Function dr_using_app_state 

pub unsafe extern "C" fn dr_using_app_state(
    drcontext: *mut c_void,
) -> bool_
Returns whether the given thread indicated by \p drcontext is currently using the application version of its system state. \sa dr_switch_to_dr_state(), dr_switch_to_app_state().

This function does not indicate whether the machine context (registers) contains application state or not.

On Linux, DR very rarely switches the system state, while on Windows DR switches the system state to the DR and client version on every event callback or clean call.