drfront_dir_try_writable

Function drfront_dir_try_writable 

pub unsafe extern "C" fn drfront_dir_try_writable(
    path: *const c_char,
    is_writable: *mut bool_,
) -> drfront_status_t
This routine checks whether a file can be created inside the directory specified by \p path.

@param[in] path The path to be checked @param[out] is_writable Returns whether files can be created in \p path.