pub unsafe extern "C" fn drfront_remove_dir(
dir: *const c_char,
) -> drfront_status_tExpand description
This routine removes the empty directory specified in \p dir.
@param[in] dir Name of directory to remove.
pub unsafe extern "C" fn drfront_remove_dir(
dir: *const c_char,
) -> drfront_status_tThis routine removes the empty directory specified in \p dir.
@param[in] dir Name of directory to remove.