instr_create

Function instr_create 

pub unsafe extern "C" fn instr_create(
    drcontext: *mut c_void,
) -> *mut instr_t
Returns an initialized instr_t allocated on the thread-local heap. Sets the x86/x64 mode of the returned instr_t to the mode of dcontext. The instruction should be de-allocated with instr_destroy(), which will be called automatically if this instruction is added to the instruction list passed to the basic block or trace events.