instr_make_persistent

Function instr_make_persistent 

pub unsafe extern "C" fn instr_make_persistent(
    drcontext: *mut c_void,
    instr: *mut instr_t,
)
Calling this function with \p instr makes it safe to keep the instruction around indefinitely when its raw bits point into the cache. The function allocates memory local to \p instr to hold a copy of the raw bits. If this was not done, the original raw bits could be deleted at some point. Making an instruction persistent is necessary if you want to keep it beyond returning from the call that produced the instruction.