instr_memory_reference_size

Function instr_memory_reference_size 

pub unsafe extern "C" fn instr_memory_reference_size(
    instr: *mut instr_t,
) -> uint
Calculates the size, in bytes, of the memory read or write of \p instr. If \p instr does not reference memory, or is invalid, returns 0. If \p instr is a repeated string instruction, considers only one iteration. If \p instr uses vector addressing (VSIB, introduced in AVX2), considers only the size of each separate memory access.