instr_opcode_valid

Function instr_opcode_valid 

pub unsafe extern "C" fn instr_opcode_valid(
    instr: *mut instr_t,
) -> bool_
Returns true iff \p instr’s opcode is valid. If the opcode is ever set to other than OP_INVALID or OP_UNDECODED it is assumed to be valid. However, calling instr_get_opcode() will attempt to decode a valid opcode, hence the purpose of this routine.