instr_valid

Function instr_valid 

pub unsafe extern "C" fn instr_valid(instr: *mut instr_t) -> bool_
Returns true iff \p instr’s opcode is NOT OP_INVALID. Not to be confused with an invalid opcode, which can be OP_INVALID or OP_UNDECODED. OP_INVALID means an instruction with no valid fields: raw bits (may exist but do not correspond to a valid instr), opcode, eflags, or operands. It could be an uninitialized instruction or the result of decoding an invalid sequence of bytes.