pub unsafe extern "C" fn opnd_is_memory_reference(
opnd: opnd_t,
) -> bool_Expand description
Returns true iff \p opnd is a (near or far) memory reference operand of any type: base-disp, absolute address, or pc-relative address.
This routine (along with all other opnd_ routines) does consider multi-byte nops that use addressing operands, or the #OP_lea instruction’s source operand, to be memory references: i.e., it only considers whether the operand calculates an address. Use instr_reads_memory() to operate on a higher semantic level and rule out these corner cases.