_dr_mcontext_t

Struct _dr_mcontext_t 

#[repr(C)]
pub struct _dr_mcontext_t {
Show 23 fields pub size: usize, pub flags: dr_mcontext_flags_t, pub __bindgen_anon_1: _dr_mcontext_t__bindgen_ty_1, pub __bindgen_anon_2: _dr_mcontext_t__bindgen_ty_2, pub __bindgen_anon_3: _dr_mcontext_t__bindgen_ty_3, pub __bindgen_anon_4: _dr_mcontext_t__bindgen_ty_4, pub __bindgen_anon_5: _dr_mcontext_t__bindgen_ty_5, pub __bindgen_anon_6: _dr_mcontext_t__bindgen_ty_6, pub __bindgen_anon_7: _dr_mcontext_t__bindgen_ty_7, pub __bindgen_anon_8: _dr_mcontext_t__bindgen_ty_8, pub r8: reg_t, pub r9: reg_t, pub r10: reg_t, pub r11: reg_t, pub r12: reg_t, pub r13: reg_t, pub r14: reg_t, pub r15: reg_t, pub __bindgen_anon_9: _dr_mcontext_t__bindgen_ty_9, pub __bindgen_anon_10: _dr_mcontext_t__bindgen_ty_10, pub padding: [byte; 48], pub __bindgen_anon_11: _dr_mcontext_t__bindgen_ty_11, pub opmask: [dr_opmask_t; 8],
}
Machine context structure.

Fields

size: usize

The size of this structure. This field must be set prior to filling in the fields to support forward compatibility.

flags: dr_mcontext_flags_t

The valid fields of this structure. This field must be set prior to filling in the fields. For input requests (dr_get_mcontext()), this indicates which fields should be written. Writing the multimedia fields frequently can incur a performance hit. For output requests (dr_set_mcontext() and dr_redirect_execution()), this indicates which fields will be copied to the actual context.

__bindgen_anon_1: _dr_mcontext_t__bindgen_ty_1__bindgen_anon_2: _dr_mcontext_t__bindgen_ty_2__bindgen_anon_3: _dr_mcontext_t__bindgen_ty_3__bindgen_anon_4: _dr_mcontext_t__bindgen_ty_4__bindgen_anon_5: _dr_mcontext_t__bindgen_ty_5__bindgen_anon_6: _dr_mcontext_t__bindgen_ty_6__bindgen_anon_7: _dr_mcontext_t__bindgen_ty_7__bindgen_anon_8: _dr_mcontext_t__bindgen_ty_8r8: reg_t

< The r8 register. \note For 64-bit DR builds only.

r9: reg_t

< The r9 register. \note For 64-bit DR builds only.

r10: reg_t

< The r10 register. \note For 64-bit DR builds only.

r11: reg_t

< The r11 register. \note For 64-bit DR builds only.

r12: reg_t

< The r12 register. \note For 64-bit DR builds only.

r13: reg_t

< The r13 register. \note For 64-bit DR builds only.

r14: reg_t

< The r14 register. \note For 64-bit DR builds only.

r15: reg_t

< The r15 register. \note For 64-bit DR builds only.

__bindgen_anon_9: _dr_mcontext_t__bindgen_ty_9__bindgen_anon_10: _dr_mcontext_t__bindgen_ty_10padding: [byte; 48]

< The padding to get zmm field 64-byte aligned.

__bindgen_anon_11: _dr_mcontext_t__bindgen_ty_11opmask: [dr_opmask_t; 8]

Storage for #MCXT_NUM_OPMASK_SLOTS mask registers as part of AVX-512.