_dr_memory_dump_spec_t

Struct _dr_memory_dump_spec_t 

#[repr(C)]
pub struct _dr_memory_dump_spec_t { pub size: usize, pub flags: dr_memory_dump_flags_t, pub label: *const c_char, pub ldmp_path: *mut c_char, pub ldmp_path_size: usize, pub elf_path: *mut c_char, pub elf_path_size: usize, }
Indicates the type of memory dump for dr_create_memory_dump().

Fields

size: usize

The size of this structure. Set this to sizeof(dr_memory_dump_spec_t).

flags: dr_memory_dump_flags_t

The type of memory dump requested.

label: *const c_char

This field only applies to #DR_MEMORY_DUMP_LDMP. This string is stored inside the ldmp as the reason for the dump.

ldmp_path: *mut c_char

This field only applies to #DR_MEMORY_DUMP_LDMP. This is an optional output field that, if non-NULL, will be written with the path to the created file.

ldmp_path_size: usize

This field only applies to #DR_MEMORY_DUMP_LDMP. This is the maximum size, in bytes, of ldmp_path.

elf_path: *mut c_char

This field only applies to #DR_MEMORY_DUMP_ELF. This is an optional output field that, if non-NULL, will be written with the path to the created file.

elf_path_size: usize

This field only applies to #DR_MEMORY_DUMP_ELF. This is the maximum size, in bytes, of elf_path.