_dr_stats_t

Struct _dr_stats_t 

#[repr(C)]
pub struct _dr_stats_t {
Show 15 fields pub size: usize, pub basic_block_count: uint64, pub peak_num_threads: uint64, pub num_threads_created: uint64, pub synchs_not_at_safe_spot: uint64, pub peak_vmm_blocks_unreach_heap: uint64, pub peak_vmm_blocks_unreach_stack: uint64, pub peak_vmm_blocks_unreach_special_heap: uint64, pub peak_vmm_blocks_unreach_special_mmap: uint64, pub peak_vmm_blocks_reach_heap: uint64, pub peak_vmm_blocks_reach_cache: uint64, pub peak_vmm_blocks_reach_special_heap: uint64, pub peak_vmm_blocks_reach_special_mmap: uint64, pub num_native_signals: uint64, pub num_cache_exits: uint64,
}
Used by dr_get_stats() and dr_app_stop_and_cleanup_with_stats()

Fields

size: usize

The size of this structure. Set this to sizeof(dr_stats_t).

basic_block_count: uint64

The total number of basic blocks ever built so far, globally. This includes duplicates and blocks that were deleted for consistency or capacity reasons or thread-private caches.

peak_num_threads: uint64

Peak number of simultaneous threads under DR control.

num_threads_created: uint64

Accumulated total number of threads encountered by DR.

synchs_not_at_safe_spot: uint64

Thread synchronization attempts retried due to the target thread being at an un-translatable spot.

peak_vmm_blocks_unreach_heap: uint64

Peak number of memory blocks used for unreachable heaps.

peak_vmm_blocks_unreach_stack: uint64

Peak number of memory blocks used for (unreachable) thread stacks.

peak_vmm_blocks_unreach_special_heap: uint64

Peak number of memory blocks used for unreachable specialized heaps.

peak_vmm_blocks_unreach_special_mmap: uint64

Peak number of memory blocks used for other unreachable mappings.

peak_vmm_blocks_reach_heap: uint64

Peak number of memory blocks used for reachable heaps.

peak_vmm_blocks_reach_cache: uint64

Peak number of memory blocks used for (reachable) code caches.

peak_vmm_blocks_reach_special_heap: uint64

Peak number of memory blocks used for reachable specialized heaps.

peak_vmm_blocks_reach_special_mmap: uint64

Peak number of memory blocks used for other reachable mappings.

num_native_signals: uint64

Signals delivered to native threads.

num_cache_exits: uint64

Number of exits from the code cache.