_module_names_t

Struct _module_names_t 

#[repr(C)]
pub struct _module_names_t { pub module_name: *const c_char, pub file_name: *const c_char, pub inode: uint64, }
Holds the names of a module. This structure contains multiple fields corresponding to different sources of a module name. Note that some of these names may not exist for certain modules. It is highly likely, however, that at least one name is available. Use dr_module_preferred_name() on the parent _module_data_t to get the preferred name of the module.

Fields

module_name: *const c_char

< On windows this name comes from the PE header exports section (NULL if the module has no exports section). On Linux the name will come from the ELF DYNAMIC program header (NULL if the module has no SONAME entry).

file_name: *const c_char

< The file name used to load this module. Note - on Windows this is not always available.

inode: uint64

< The inode of the module file mapped in.