dr_exit_flags_t

Struct dr_exit_flags_t 

#[repr(transparent)]
pub struct dr_exit_flags_t(pub c_uint);
Flags controlling thread behavior at process exit time in release build. See dr_set_process_exit_behavior() for further details.

Tuple Fields

0: c_uint

Implementations

Source

impl dr_exit_flags_t

pub const DR_EXIT_MULTI_THREAD: dr_exit_flags_t

Do not guarantee that the process exit event is executed single-threaded. This is equivalent to specifying the \p -multi_thread_exit runtime option. Setting this flag can improve process exit performance, but usually only when the #DR_EXIT_SKIP_THREAD_EXIT flag is also set, or when no thread exit events are registered.

Source

impl dr_exit_flags_t

pub const DR_EXIT_SKIP_THREAD_EXIT: dr_exit_flags_t

Do not invoke thread exit event callbacks at process exit time. Thread exit event callbacks will still be invoked at other times. This is equivalent to setting the \p -skip_thread_exit_at_exit runtime option. Setting this flag can improve process exit performance, but usually only when the #DR_EXIT_MULTI_THREAD flag is also set, or when no process exit event is registered.