dr_mcontext_flags_t

Struct dr_mcontext_flags_t 

#[repr(transparent)]
pub struct dr_mcontext_flags_t(pub c_uint);
Values for the flags field of dr_mcontext_t

Tuple Fields

0: c_uint

Implementations

Source

impl dr_mcontext_flags_t

pub const DR_MC_INTEGER: dr_mcontext_flags_t

On x86, selects the xdi, xsi, xbp, xbx, xdx, xcx, xax, and r8-r15 fields (i.e., all of the general-purpose registers excluding xsp, xip, and xflags). On ARM, selects r0-r12 and r14. On AArch64, selects r0-r30.

Source

impl dr_mcontext_flags_t

pub const DR_MC_CONTROL: dr_mcontext_flags_t

On x86, selects the xsp, xflags, and xip fields. On ARM, selects the sp, pc, and cpsr fields. On AArch64, selects the sp, pc, and nzcv fields. On RISC-V, selects the sp, pc and fcsr fields. \note: The xip/pc field is only honored as an input for dr_redirect_execution(), and as an output for system call events.

Source

impl dr_mcontext_flags_t

pub const DR_MC_MULTIMEDIA: dr_mcontext_flags_t

Selects the simd fields. This flag is ignored unless dr_mcontext_xmm_fields_valid() returns true. If dr_mcontext_xmm_fields_valid() returns false, the application values of the multimedia registers remain in the registers themselves.

Source

impl dr_mcontext_flags_t

pub const DR_MC_ALL: dr_mcontext_flags_t

Selects all fields