#[repr(C)]pub struct dr_time_t {
pub year: uint,
pub month: uint,
pub day_of_week: uint,
pub day: uint,
pub hour: uint,
pub minute: uint,
pub second: uint,
pub milliseconds: uint,
}Expand description
Structure written by dr_get_time() to specify the current time.
Fields
year: uint< The current year.
month: uint< The current month, in the range 1 to 12.
day_of_week: uint< The day of the week, in the range 0 to 6.
day: uint< The day of the month, in the range 1 to 31.
hour: uint< The hour of the day, in the range 0 to 23.
minute: uint< The minutes past the hour.
second: uint< The seconds past the minute.
milliseconds: uint< The milliseconds past the second.