#[repr(C)]pub struct instr_t {
pub black_box_uint: [uint; 28],
}Expand description
Internal structure of instr_t is below abstraction layer, but we provide its size so that it can be used in stack variables instead of always allocated on the heap.
Fields
black_box_uint: [uint; 28]Trait Implementations