pub unsafe extern "C" fn __wrap_realloc(
mem: *mut c_void,
size: usize,
) -> *mut c_voidExpand description
Reallocates memory from DR’s global memory pool, but mimics the behavior of realloc. Memory must be freed with __wrap_free(). The __wrap routines are intended to be used with ld’s -wrap option; see __wrap_malloc() for more information. The returned address is guaranteed to be double-pointer-aligned: aligned to 16 bytes for 64-bit; aligned to 8 bytes for 32-bit.