pub unsafe extern "C" fn dr_client_thread_set_suspendable(
suspendable: bool_,
) -> bool_Expand description
Can only be called from a client thread: returns false if called from a non-client thread.
Controls whether a client thread created with dr_create_client_thread() will be suspended by DR for synchronization operations such as flushing or client requests like dr_suspend_all_other_threads(). A client thread that spends a lot of time holding locks can gain greater performance by not being suspended.
A client thread \b will be suspended for a thread termination operation, including at process exit, regardless of its suspendable requests.