pub unsafe extern "C" fn dr_create_dir(fname: *const c_char) -> bool_Expand description
Creates a new directory. Fails if the directory already exists or if it can’t be created. Relative path support on Windows is identical to that described in dr_open_file().