pub unsafe extern "C" fn dr_get_option_array(
client_id: client_id_t,
argc: *mut c_int,
argv: *mut *mut *const c_char,
) -> bool_Expand description
Returns the client-specific option string specified at client registration, parsed into an array of \p argc separate option tokens stored in \p argv. This is the same array of arguments passed to the dr_client_main() routine.