pub unsafe extern "C" fn dr_hashtable_destroy(
drcontext: *mut c_void,
htable: *mut c_void,
)Expand description
Destroys a hashtable created by dr_hashtable_create().
@param[in] drcontext Must be the same context passed to dr_hashtable_create(). @param[in] htable A pointer to the table itself, returned by dr_hashtable_create().