pub unsafe extern "C" fn dr_hashtable_remove(
drcontext: *mut c_void,
htable: *mut c_void,
key: ptr_uint_t,
) -> bool_Expand description
Removes an entry for the given key.
@param[in] drcontext Must be the same context passed to dr_hashtable_create(). @param[in] htable A pointer to the table itself, returned by dr_hashtable_create(). @param[in] key The key to remove.
@return whether the key was found.