pub unsafe extern "C" fn dr_insert_call_ex(
drcontext: *mut c_void,
ilist: *mut instrlist_t,
where_: *mut instr_t,
encode_pc: *mut byte,
callee: *mut c_void,
num_args: uint,
...
) -> bool_Expand description
Identical to dr_insert_call() except it takes in \p encode_pc indicating roughly where the call sequence will be encoded. If \p callee is not reachable from \p encode_pc plus or minus one page, an indirect call will be used instead of the direct call used by dr_insert_call(). The indirect call overwrites the r11 register.
\return true if the inserted call is direct and false if indirect.