pub unsafe extern "C" fn dr_map_file(
f: file_t,
size: *mut usize,
offs: uint64,
addr: app_pc,
prot: uint,
flags: uint,
) -> *mut c_voidExpand description
Memory-maps \p size bytes starting at offset \p offs from the file \p f at address \p addr with privileges \p prot.
@param[in] f The file to map. @param[in,out] size The requested size to map. Upon successful return, contains the actual mapped size. @param[in] offs The offset within the file at which to start the map. @param[in] addr The requested start address of the map. Unless \p fixed is true, this is just a hint and may not be honored. @param[in] prot The access privileges of the mapping, composed of the DR_MEMPROT_READ, DR_MEMPROT_WRITE, and DR_MEMPROT_EXEC bits. @param[in] flags Optional DR_MAP_* flags.
\note Mapping image files for execution is not supported.
\return the start address of the mapping, or NULL if unsuccessful.