pub unsafe extern "C" fn dr_module_iterator_start() -> *mut dr_module_iterator_tExpand description
Initialize a new module iterator. The returned module iterator contains a snapshot of the modules loaded at the time it was created. Use dr_module_iterator_hasnext() and dr_module_iterator_next() to walk the loaded modules. Call dr_module_iterator_stop() when finished to release the iterator. \note The iterator does not prevent modules from being loaded or unloaded while the iterator is being walked.