pub unsafe extern "C" fn dr_prepopulate_cache(
tags: *mut app_pc,
tags_count: usize,
) -> bool_Expand description
Intended to be called between dr_app_setup() and dr_app_start() to pre-create code cache fragments for each basic block address in the \p tags array. This speeds up the subsequent attach when dr_app_start() is called. If any code in the passed-in tags array is not readable, it is up to the caller to handle any fault, as DR’s own signal handlers are not enabled at this point. Returns whether successful.