pub unsafe extern "C" fn dr_register_thread_init_event(
func: Option<unsafe extern "C" fn(drcontext: *mut c_void)>,
)Expand description
Registers a callback function for the thread initialization event. DR calls \p func whenever the application creates a new thread.